@@ -9,6 +9,8 @@ import aurcore as aur
 from .response import Response
 from .. import errors
 from ..auth import Auth, AuthAware
+from loguru import logger
+from ..context import GuildMessageCtx
 
 if ty.TYPE_CHECKING:
    from ..types_ import *
@@ -43,8 +45,9 @@ class Command(aur.util.AutoRepr, AuthAware):
          name: str,
          parsed: bool,
          decompose: bool,
+         allow_dm: bool,
          default_auths: ty.List[Record],
-         provide_auth,
+         override_auths: ty.List[Record],
    ):
       self.func = func
       self.flux = flux
@@ -53,12 +56,13 @@ class Command(aur.util.AutoRepr, AuthAware):
       self.doc = inspect.getdoc(func)
       self.parsed = False  # todo: argparser
       self.decompose = decompose
-
+      self.allow_dm = allow_dm
       # self.checks: ty.List[ty.Callable[[GuildMessageContext], ty.Union[bool, ty.Awaitable[bool]]]] = []
       self.builtin = False
       # self.argparser: ty.Optional[argh.ArgumentParser] = None
       self.default_auths_: ty.List[Record] = default_auths
-      self.provide_auth = provide_auth
+      self.override_auths_: ty.List[Record] = override_auths
+
       func_doc = inspect.getdoc(self.func)
       if not func_doc:
          raise RuntimeError(f"{self.func} lacks a docstring!")
@@ -76,44 +80,34 @@ class Command(aur.util.AutoRepr, AuthAware):
       #    self.long_usage: ty.List[ty.List[str, str]] = [doc_line.split(":") for doc_line in raw_doc.split("\n")]
 
    async def execute(self, ev: CommandEvent) -> None:
-      msg_ctx = ev.msg_ctx
-      auth_ctx = ev.auth_ctx
-      cmd_args = ev.cmd_args
+      cmd_ctx = ev.cmd_ctx
 
-      # if (self.argparser is not None) ^ self.parsed:
-      #    raise RuntimeError(f"Parsed command {self} has not been decorated with Argh")
+      if not isinstance(cmd_ctx.msg_ctx, GuildMessageCtx) and not self.allow_dm:
+         return await Response(content="Cannot be used in DMs", errored=True).execute(cmd_ctx.msg_ctx)
 
-      if not Auth.accepts(auth_ctx, self):
-         await Response(content="Forbidden", errored=True).execute(msg_ctx)
-         return
+      logger.trace(f"Command {self} executing in {cmd_ctx.msg_ctx}")
+
+      if not Auth.accepts_all(cmd_ctx.auth_ctxs, self):
+         return await Response(content="Forbidden", errored=True).execute(cmd_ctx.msg_ctx)
 
       try:
-         auths = {"auth_ctx": auth_ctx} if self.provide_auth else {}
-         with msg_ctx.channel.typing():
-            # if self.parsed:
-            # assert self.argparser is not None  # typing
-            # res = self.func(msg_ctx, **auths, **self.argparser.parse_args(cmd_args.split(" ") if cmd_args else []).__dict__)
-            # else:
+         with cmd_ctx.msg_ctx.channel.typing():
             if self.decompose:
-               res = self.func(msg_ctx, *ev.args, **ev.kwargs, **auths)
+               res = self.func(cmd_ctx, *ev.args, **ev.kwargs)
             else:
-               res = self.func(msg_ctx, cmd_args, **auths)
+               res = self.func(cmd_ctx, ev.cmd_args)
 
-         async for resp in aur.util.AwaitableAiter(res):
-            await resp.execute(msg_ctx)
+            async for resp in aur.util.AwaitableAiter(res):
+               await resp.execute(cmd_ctx)
       except errors.CommandError as e:
          info_message = f"{e}"
-         # if self.argparser:
-         #    info_message += f"\n```{self.argparser.format_help()}```"
-         await Response(content=info_message, errored=True).execute(msg_ctx)
+         await Response(content=info_message, errored=True).execute(cmd_ctx)
       except errors.CommandInfo as e:
          info_message = f"{e}"
-         # if self.argparser:
-         #    info_message += f"\n```{self.argparser.format_help()}```"
-         await Response(content=info_message).execute(msg_ctx)
+         await Response(content=info_message).execute(cmd_ctx)
       except Exception as e:
-         await Response(content=f"```Unexpected Exception:\n{str(e)}\n```", errored=True).execute(msg_ctx)
-         print(traceback.format_exc())
+         await Response(content=f"```Unexpected Exception:\n{str(e)}\n```", errored=True).execute(cmd_ctx)
+         logger.error(traceback.format_exc())
 
    @property
    def auth_id(self):
@@ -123,6 +117,12 @@ class Command(aur.util.AutoRepr, AuthAware):
    def default_auths(self):
       return self.default_auths_
 
+   @property
+   def override_auths(self):
+      return self.default_auths_
+
+   def __str__(self):
+      return f"Command {self.name} in {self.cog}: {self.func}"
 # class CommandCheck:
 #    CheckPredicate: ty.TypeAlias = ty.Callable[[GuildMessageContext], ty.Awaitable[bool]]
 #    CommandTransformDeco: ty.TypeAlias = ty.Callable[[Command], Command]
